@@ -8,7 +8,7 @@ require File::Spec;
 use Safe;
 use YAML qw(LoadFile);
 
-our $VERSION = '0.97';
+our $VERSION = '0.99';
 
 sub new {
   my ($class, %opts) = @_;
@@ -20,7 +20,7 @@ sub new {
   die qq{Please supply a PPM::Make::Search object}
     unless (defined $search and (ref($search) eq 'PPM::Make::Search'));
   my $self = {info => {}, cwd => $cwd,
-	      search => $search, no_remote_lookup => $no_remote_lookup};
+              search => $search, no_remote_lookup => $no_remote_lookup};
   bless $self, $class;
 }
 
@@ -50,7 +50,7 @@ sub meta {
 sub parse_build {
   my $self = shift;
   my $bp = '_build/build_params';
-#  open(my $fh, $bp) or die "Couldn't open $bp: $!";
+#  open(my $fh, '<', $bp) or die "Couldn't open $bp: $!";
 #  my @lines = <$fh>;
 #  close $fh;
 #  my $content = join "\n", @lines;
@@ -108,7 +108,7 @@ sub parse_yaml {
 
 sub parse_makepl {
   my $self = shift;
-  open(my $fh, 'Makefile.PL') or die "Couldn't open Makefile.PL: $!";
+  open(my $fh, '<', 'Makefile.PL') or die "Couldn't open Makefile.PL: $!";
   my @lines = <$fh>;
   close $fh;
   my $makeargs;
@@ -144,7 +144,7 @@ sub parse_make {
                   VERSION VERSION_FROM PREREQ_PM);
   my $re = join '|', @wanted;
   my @lines;
-  open(my $fh, 'Makefile') or die "Couldn't open Makefile: $!";
+  open(my $fh, '<', 'Makefile') or die "Couldn't open Makefile: $!";
   while (<$fh>) {
     if (not $flag and /MakeMaker Parameters/) {
       $flag = 1;
@@ -244,7 +244,7 @@ sub guess_abstract {
       $guess = $info->{NAME} . ".$ext";
     }
     finddepth(sub{$_ eq $guess && ($hit = $File::Find::name) 
-		    && ($hit !~ m!blib/!)}, $cwd);
+                    && ($hit !~ m!blib/!)}, $cwd);
     next unless ($hit and -f $hit);
     print "Trying to get ABSTRACT from $hit ...\n";
     $result = parse_abstract($info->{NAME}, $hit);
@@ -255,13 +255,13 @@ sub guess_abstract {
     my $mod_results = $search->{mod_results};
     if (defined $mod_results and defined $mod_results->{$try}) {
       return $mod_results->{$try}->{mod_abs}
-	       if defined $mod_results->{$try}->{mod_abs};
+               if defined $mod_results->{$try}->{mod_abs};
     }
     if ($search->search($try, mode => 'mod')) {
       $mod_results = $search->{mod_results};
       if (defined $mod_results and defined $mod_results->{$try}) {
         return $mod_results->{$try}->{mod_abs}
-	        if defined $mod_results->{$try}->{mod_abs};
+                if defined $mod_results->{$try}->{mod_abs};
       }
     }
     else {
@@ -273,13 +273,13 @@ sub guess_abstract {
     my $dist_results = $search->{dist_results};
     if (defined $dist_results and defined $dist_results->{$try}) {
       return $dist_results->{$try}->{dist_abs}
-	    if defined $dist_results->{$try}->{dist_abs};
+            if defined $dist_results->{$try}->{dist_abs};
     }
     if ($search->search($try, mode => 'dist')) {
       $dist_results = $search->{dist_results};
       if (defined $dist_results and defined $dist_results->{$try}) {
-	    return $dist_results->{$try}->{dist_abs}
-	      if defined $dist_results->{$try}->{dist_abs};
+            return $dist_results->{$try}->{dist_abs}
+              if defined $dist_results->{$try}->{dist_abs};
       }
     }
     else {
@@ -325,7 +325,7 @@ sub guess_bundle {
       $guess = $info->{NAME} . ".$ext";
     }
     finddepth(sub{$_ eq $guess && ($hit !~ m!blib/!)
-		    && ($hit = $File::Find::name) }, $cwd);
+                    && ($hit = $File::Find::name) }, $cwd);
     next unless (-f $hit);
     print "Trying to get Bundle/Task info from $hit ...\n";
     $result = parse_bundle($hit);
@@ -339,7 +339,7 @@ sub parse_bundle {
   my @result;
   local $/ = "\n";
   my $in_cont = 0;
-  open(my $fh, $file) or die "Couldn't open $file: $!";
+  open(my $fh, '<', $file) or die "Couldn't open $file: $!";
   while (<$fh>) {
     $in_cont = m/^=(?!head1\s+CONTENTS)/ ? 0 :
       m/^=head1\s+CONTENTS/ ? 1 : $in_cont;
@@ -380,13 +380,13 @@ sub guess_author {
     my $mod_results = $search->{mod_results};
     if (defined $mod_results and defined $mod_results->{$try}) {
       return $mod_results->{$try}->{author}
-	if defined $mod_results->{$try}->{author};
+        if defined $mod_results->{$try}->{author};
     }
     if ($search->search($try, mode => 'mod')) {
       $mod_results = $search->{mod_results};
       if (defined $mod_results and defined $mod_results->{$try}) {
-	return $mod_results->{$try}->{author}
-	  if defined $mod_results->{$try}->{author};
+        return $mod_results->{$try}->{author}
+          if defined $mod_results->{$try}->{author};
       }
     }
     else {
@@ -398,13 +398,13 @@ sub guess_author {
     my $dist_results = $search->{dist_results};
     if (defined $dist_results and defined $dist_results->{$try}) {
       return $dist_results->{$try}->{author}
-	if defined $dist_results->{$try}->{author};
+        if defined $dist_results->{$try}->{author};
     }
     if ($search->search($try, mode => 'dist')) {
       $dist_results = $search->{dist_results};
       if (defined $dist_results and defined $dist_results->{$try}) {
-	return $dist_results->{$try}->{author}
-	  if defined $dist_results->{$try}->{author};
+        return $dist_results->{$try}->{author}
+          if defined $dist_results->{$try}->{author};
       }
     }
     else {
